@@ -1,13 +1,13 @@
 package File::Which;
 
-use 5.004;
+use 5.005003;
 use strict;
 use Exporter   ();
 use File::Spec ();
 
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK};
 BEGIN {
-	$VERSION   = '1.09';
+	$VERSION   = '1.10';
 	@ISA       = 'Exporter';
 	@EXPORT    = 'which';
 	@EXPORT_OK = 'where';
@@ -16,6 +16,7 @@ BEGIN {
 use constant IS_VMS => ($^O eq 'VMS');
 use constant IS_MAC => ($^O eq 'MacOS');
 use constant IS_DOS => ($^O eq 'MSWin32' or $^O eq 'dos' or $^O eq 'os2');
+use constant IS_CYG => ($^O eq 'cygwin');
 
 # For Win32 systems, stores the extensions used for
 # executable files
@@ -32,6 +33,10 @@ if ( IS_DOS ) {
 	}
 } elsif ( IS_VMS ) {
 	push @PATHEXT, qw{.exe .com};
+} elsif ( IS_CYG ) {
+	# See this for more info
+	# http://cygwin.com/cygwin-ug-net/using-specialnames.html#pathnames-exe
+	push @PATHEXT, qw{.exe .com};
 }
 
 sub which {
@@ -89,7 +94,7 @@ sub which {
 					IS_MAC
 					||
 					(
-						IS_DOS
+						( IS_DOS or IS_CYG )
 						and
 						grep {
 							$file =~ /$_\z/i
@@ -210,22 +215,39 @@ report of how it went.
 
 File::Spec adds the current directory to the front of PATH if on
 Win32, VMS or MacOS. I have no knowledge of those so don't know if the
-current directory is searced first or not. Could someone please tell
+current directory is searched first or not. Could someone please tell
 me?
 
 =head1 SUPPORT
 
-Bugs should be reported via the CPAN bug tracker at
+Bugs should be reported via the GitHub issue tracker
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Which>
+L<https://github.com/plicease/File-Which/issues>
 
 For other issues, contact the maintainer.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<pwhich>
+
+Command line interface to this module.
+
+=item L<Devel::CheckBin>
+
+This module proports to "check that a command is available", but does not
+provide any documentation on how you might use it.
+
+=back
+
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-Per Einar Ellefsen E<lt>pereinar@cpan.orgE<gt>
+Previous maintainer: Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+Original author: Per Einar Ellefsen E<lt>pereinar@cpan.orgE<gt>
 
 Originated in F<modperl-2.0/lib/Apache/Build.pm>. Changed for use in DocSet
 (for the mod_perl site) and Win32-awareness by me, with slight modifications
